==> order-center-infrastructure-2.0.9-CLOUD-TEST-20220408.014252-61-sources.jar: com/tydic/dyc/oc/repository/impl/UocAuditOrderRepositoryImpl.java <==
package com.tydic.dyc.oc.repository.impl;

import cn.hutool.core.util.ObjectUtil;
import com.tydic.dyc.oc.model.audit.UocAuditOrderDo;
import com.tydic.dyc.oc.model.audit.qrybo.UocAuditOrderQryBo;
import com.tydic.dyc.oc.model.audit.sub.UocApprovalObj;
import com.tydic.dyc.oc.model.audit.sub.UocAuditOrder;
import com.tydic.dyc.oc.repository.UocAuditOrderRepository;
import com.tydic.dyc.oc.repository.dao.UocApprovalLogMapper;
import com.tydic.dyc.oc.repository.dao.UocApprovalObjMapper;
import com.tydic.dyc.oc.repository.dao.UocAuditOrderMapper;
import com.tydic.dyc.oc.repository.po.UocApprovalLogPo;
import com.tydic.dyc.oc.repository.po.UocApprovalObjPo;
import com.tydic.dyc.oc.repository.po.UocAuditOrderPo;
import com.tydic.dyc.oc.utils.UocRu;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.ArrayList;
import java.util.List;

/**
 * 标题:UocAuditOrderRepositoryImpl
 * 说明:
 * 时间:2022/3/10 17:27
 * 作者:田桂银
 */
@Service
public class UocAuditOrderRepositoryImpl implements UocAuditOrderRepository {


    @Autowired
    private UocAuditOrderMapper uocAuditOrderMapper;

    @Autowired
    private UocApprovalObjMapper uocApprovalObjMapper;

    @Autowired
    private UocApprovalLogMapper uocApprovalLogMapper;


    @Override
    public UocAuditOrderDo saveAudit(UocAuditOrderDo orderDo) {
        UocAuditOrderPo auditPo = UocRu.js(orderDo, UocAuditOrderPo.class);
        uocAuditOrderMapper.insert(auditPo);

        List<UocApprovalObjPo> poList = new ArrayList<>();
        List<UocApprovalObj> approvalObjs = orderDo.getApprovalObjs();
        for (UocApprovalObj approvalObj : approvalObjs) {
            UocApprovalObjPo po = UocRu.js(approvalObj, UocApprovalObjPo.class);
            po.setAuditOrderId(orderDo.getAuditOrderId());
            poList.add(po);
        }
        uocApprovalObjMapper.insertBatch(poList);
        if (null != orderDo.getApprovalLog()) {
            uocApprovalLogMapper.insert(UocRu.js(orderDo.getApprovalLog(), UocApprovalLogPo.class));
        }
        return orderDo;
    }

    @Override
    public UocAuditOrderDo updateApprove(UocAuditOrderDo updateDo) {
        UocAuditOrderPo set = UocRu.js(updateDo, UocAuditOrderPo.class);
        UocAuditOrderPo where = new UocAuditOrderPo();
        where.setOrderId(updateDo.getOrderId());
        where.setAuditOrderId(where.getAuditOrderId());
        uocAuditOrderMapper.updateBy(set, where);
        if (null != updateDo.getApprovalLog()) {
            uocApprovalLogMapper.insert(UocRu.js(updateDo.getApprovalLog(), UocApprovalLogPo.class));
        }
        return updateDo;
    }

    @Override
    public List<UocApprovalObj> qryApprovealObj(UocApprovalObj obj) {
        List<UocApprovalObjPo> list = uocApprovalObjMapper.getList(UocRu.js(obj, UocApprovalObjPo.class));
        return ObjectUtil.isNotEmpty(list) ? UocRu.jsl(list, UocApprovalObj.class) : new ArrayList<>();
    }

    @Override
    public List<UocAuditOrder> qryAuditOrderList(UocAuditOrderQryBo qryBo) {
        List<UocAuditOrderPo> list = uocAuditOrderMapper.getList(UocRu.js(qryBo, UocAuditOrderPo.class));
        return ObjectUtil.isNotEmpty(list) ? UocRu.jsl(list, UocAuditOrder.class) : new ArrayList<>();
    }

    @Override
    public void saveAuditLog(UocAuditOrderDo orderDo) {
        if (null != orderDo && null != orderDo.getApprovalLog()) {
            uocApprovalLogMapper.insert(UocRu.js(orderDo.getApprovalLog(), UocApprovalLogPo.class));
        }
    }
}

==> order-center-infrastructure-3.1.0-CLOUD-TEST-20230918.052400-110-sources.jar: com/tydic/dyc/oc/repository/impl/UocAuditOrderRepositoryImpl.java <==
package com.tydic.dyc.oc.repository.impl;

import cn.hutool.core.util.ObjectUtil;
import com.tydic.dyc.oc.constants.UocDicConstant;
import com.tydic.dyc.oc.model.audit.UocAuditOrderDo;
import com.tydic.dyc.oc.model.audit.qrybo.UocApprovalLogQryBo;
import com.tydic.dyc.oc.model.audit.qrybo.UocApprovalObjQryBo;
import com.tydic.dyc.oc.model.audit.qrybo.UocAuditOrderQryBo;
import com.tydic.dyc.oc.model.audit.sub.UocApprovalLog;
import com.tydic.dyc.oc.model.audit.sub.UocApprovalObj;
import com.tydic.dyc.oc.model.audit.sub.UocAuditOrder;
import com.tydic.dyc.oc.repository.UocAuditOrderRepository;
import com.tydic.dyc.oc.repository.dao.UocApprovalLogMapper;
import com.tydic.dyc.oc.repository.dao.UocApprovalObjMapper;
import com.tydic.dyc.oc.repository.dao.UocAuditOrderMapper;
import com.tydic.dyc.oc.repository.po.UocApprovalLogPo;
import com.tydic.dyc.oc.repository.po.UocApprovalObjPo;
import com.tydic.dyc.oc.repository.po.UocAuditOrderPo;
import com.tydic.dyc.oc.utils.UocRu;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.ArrayList;
import java.util.List;

/**
 * 标题:UocAuditOrderRepositoryImpl
 * 说明:
 * 时间:2022/3/10 17:27
 * 作者:田桂银
 */
@Service
public class UocAuditOrderRepositoryImpl implements UocAuditOrderRepository {


    @Autowired
    private UocAuditOrderMapper uocAuditOrderMapper;

    @Autowired
    private UocApprovalObjMapper uocApprovalObjMapper;

    @Autowired
    private UocApprovalLogMapper uocApprovalLogMapper;


    @Override
    public UocAuditOrderDo saveAudit(UocAuditOrderDo orderDo) {
        UocAuditOrderPo auditPo = UocRu.js(orderDo, UocAuditOrderPo.class);
        uocAuditOrderMapper.insert(auditPo);

        List<UocApprovalObjPo> poList = new ArrayList<>();
        List<UocApprovalObj> approvalObjs = orderDo.getApprovalObjs();
        for (UocApprovalObj approvalObj : approvalObjs) {
            UocApprovalObjPo po = UocRu.js(approvalObj, UocApprovalObjPo.class);
            po.setAuditOrderId(orderDo.getAuditOrderId());
            poList.add(po);
        }
        uocApprovalObjMapper.insertBatch(poList);
        if (null != orderDo.getApprovalLog()) {
            uocApprovalLogMapper.insert(UocRu.js(orderDo.getApprovalLog(), UocApprovalLogPo.class));
        }
        return orderDo;
    }

    @Override
    public UocAuditOrderDo updateApprove(UocAuditOrderDo updateDo) {
        UocAuditOrderPo set = UocRu.js(updateDo, UocAuditOrderPo.class);
        UocAuditOrderPo where = new UocAuditOrderPo();
        where.setOrderId(updateDo.getOrderId());
        where.setAuditOrderId(updateDo.getAuditOrderId());
        uocAuditOrderMapper.updateBy(set, where);
        if (null != updateDo.getApprovalLog()) {
            uocApprovalLogMapper.insert(UocRu.js(updateDo.getApprovalLog(), UocApprovalLogPo.class));
        }
        return updateDo;
    }

    @Override
    public List<UocApprovalObj> qryApprovealObj(UocApprovalObjQryBo obj) {
        List<UocApprovalObjPo> list = uocApprovalObjMapper.getList(UocRu.js(obj, UocApprovalObjPo.class));
        return ObjectUtil.isNotEmpty(list) ? UocRu.jsl(list, UocApprovalObj.class) : new ArrayList<>();
    }

    @Override
    public List<UocAuditOrder> qryAuditOrderList(UocAuditOrderQryBo qryBo) {
        List<UocAuditOrderPo> list = uocAuditOrderMapper.getList(UocRu.js(qryBo, UocAuditOrderPo.class));
        return ObjectUtil.isNotEmpty(list) ? UocRu.jsl(list, UocAuditOrder.class) : new ArrayList<>();
    }

    @Override
    public void saveAuditLog(UocAuditOrderDo orderDo) {
        if (null != orderDo && null != orderDo.getApprovalLog()) {
            uocApprovalLogMapper.insert(UocRu.js(orderDo.getApprovalLog(), UocApprovalLogPo.class));
        }
    }

    @Override
    public UocAuditOrderDo qryApprovalLog(UocApprovalLogQryBo uocApprovalLogQryBo) {
        UocApprovalLogPo uocApprovalLogPo = new UocApprovalLogPo();
        uocApprovalLogPo.setAuditOrderId(uocApprovalLogQryBo.getAuditOrderId());
        List<UocApprovalLogPo> uocApprovalLogPos = uocApprovalLogMapper.getList(uocApprovalLogPo);
        UocAuditOrderDo uocAuditOrderDo = new UocAuditOrderDo();
        List<UocApprovalLog> uocApprovalLogs = UocRu.jsl(uocApprovalLogPos, UocApprovalLog.class);
        uocAuditOrderDo.setUocApprovalLogList(uocApprovalLogs);
        return uocAuditOrderDo;
    }

    @Override
    public UocAuditOrderDo qryAuditOrder(UocAuditOrderQryBo qryBo) {
        UocAuditOrderPo modelBy = uocAuditOrderMapper.getModelBy(UocRu.js(qryBo, UocAuditOrderPo.class));
        return UocRu.js(modelBy, UocAuditOrderDo.class);
    }
    
    @Override
    public int delApprovealObj(UocApprovalObjQryBo obj) {
        UocApprovalObjPo where = new UocApprovalObjPo();
        where.setAuditOrderId(obj.getAuditOrderId());
        where.setObjId(obj.getObjId());
        where.setOrderId(obj.getOrderId());
    
        UocApprovalObjPo set = new UocApprovalObjPo();
        set.setDelTag(UocDicConstant.DELETE_TAG.DELETED);
        return uocApprovalObjMapper.updateBy(set,where);
    }
}
